This is an automated email from the ASF dual-hosted git repository.

mseidel pushed a commit to branch trunk
in repository https://gitbox.apache.org/repos/asf/openoffice.git


The following commit(s) were added to refs/heads/trunk by this push:
     new d016691  Fixed typos, removed whitespace
d016691 is described below

commit d016691d2e0980460f9df67cb8684185c68c2703
Author: mseidel <msei...@apache.org>
AuthorDate: Mon May 17 14:13:44 2021 +0200

    Fixed typos, removed whitespace
---
 main/desktop/source/deployment/misc/dp_misc.cxx    |  60 ++++----
 main/framework/source/inc/loadenv/loadenv.hxx      |  49 +++---
 main/offapi/com/sun/star/awt/AccessibleButton.idl  |  30 ++--
 .../offapi/com/sun/star/awt/AccessibleCheckBox.idl |  32 ++--
 main/offapi/com/sun/star/awt/Command.idl           | 100 ++++++------
 main/offapi/com/sun/star/awt/WindowAttribute.idl   | 167 +++++++++++----------
 main/offapi/com/sun/star/awt/WindowEvent.idl       | 134 ++++++++---------
 .../sun/star/awt/grid/DefaultGridColumnModel.idl   |  41 ++---
 .../com/sun/star/awt/tree/XTreeEditListener.idl    |  13 +-
 .../ui/Accessibility/AccessibleFilterMenu.cxx      |  44 +++---
 .../ui/slidesorter/inc/cache/SlsPageCache.hxx      |  36 ++---
 main/slideshow/source/engine/slide/slideimpl.cxx   | 144 +++++++++---------
 12 files changed, 427 insertions(+), 423 deletions(-)

diff --git a/main/desktop/source/deployment/misc/dp_misc.cxx 
b/main/desktop/source/deployment/misc/dp_misc.cxx
index 53f9020..a03c692 100644
--- a/main/desktop/source/deployment/misc/dp_misc.cxx
+++ b/main/desktop/source/deployment/misc/dp_misc.cxx
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -47,7 +47,7 @@
 #include "boost/scoped_array.hpp"
 #include "boost/shared_ptr.hpp"
 #include <comphelper/processfactory.hxx>
- 
+
 #ifdef WNT
 //#include "tools/prewin.h"
 #define UNICODE
@@ -96,29 +96,29 @@ const OUString OfficePipeId::operator () ()
     OUString userPath;
        ::utl::Bootstrap::PathStatus aLocateResult =
        ::utl::Bootstrap::locateUserInstallation( userPath );
-       if (!(aLocateResult == ::utl::Bootstrap::PATH_EXISTS || 
+       if (!(aLocateResult == ::utl::Bootstrap::PATH_EXISTS ||
                aLocateResult == ::utl::Bootstrap::PATH_VALID))
        {
                throw Exception(OUSTR("Extension Manager: Could not obtain path 
for UserInstallation."), 0);
        }
-    
+
     rtlDigest digest = rtl_digest_create( rtl_Digest_AlgorithmMD5 );
     if (digest == NULL) {
         throw RuntimeException(
             OUSTR("cannot get digest rtl_Digest_AlgorithmMD5!"), 0 );
     }
-    
+
     sal_uInt8 const * data =
         reinterpret_cast<sal_uInt8 const *>(userPath.getStr());
     sal_Size size = (userPath.getLength() * sizeof (sal_Unicode));
     sal_uInt32 md5_key_len = rtl_digest_queryLength( digest );
     ::boost::scoped_array<sal_uInt8> md5_buf( new sal_uInt8 [ md5_key_len ] );
-    
+
     rtl_digest_init( digest, data, static_cast<sal_uInt32>(size) );
     rtl_digest_update( digest, data, static_cast<sal_uInt32>(size) );
     rtl_digest_get( digest, md5_buf.get(), md5_key_len );
     rtl_digest_destroy( digest );
-    
+
     // create hex-value string from the MD5 value to keep
     // the string size minimal
     ::rtl::OUStringBuffer buf;
@@ -161,20 +161,20 @@ bool compareExtensionFolderWithLastSynchronizedFile(
         return true; //sync just in case
     }
 
-    //If last synchronized does not exist, then OOo is started for the first 
time
+    //If last synchronized does not exist, then AOO is started for the first 
time
     ::osl::DirectoryItem itemFile;
     ::osl::File::RC err2 = ::osl::DirectoryItem::get(fileURL, itemFile);
     if (err2 == ::osl::File::E_NOENT)
     {
         return true;
-        
+
     }
     else if (err2 != ::osl::File::E_None)
     {
         OSL_ENSURE(0, "Cannot access file lastsynchronized");
         return true; //sync just in case
     }
-    
+
     //compare the modification time of the extension folder and the last
     //modified file
     ::osl::FileStatus statFolder(FileStatusMask_ModifyTime);
@@ -192,7 +192,7 @@ bool compareExtensionFolderWithLastSynchronizedFile(
         else
         {
             OSL_ASSERT(0);
-            bNeedsSync = true; 
+            bNeedsSync = true;
         }
     }
     else
@@ -200,7 +200,7 @@ bool compareExtensionFolderWithLastSynchronizedFile(
         OSL_ASSERT(0);
         bNeedsSync = true;
     }
-    return bNeedsSync;    
+    return bNeedsSync;
 }
 
 bool needToSyncRepostitory(OUString const & name)
@@ -228,7 +228,7 @@ bool needToSyncRepostitory(OUString const & name)
     {
         OSL_ASSERT(0);
         return true;
-    }    
+    }
     ::rtl::Bootstrap::expandMacros(folder);
     ::rtl::Bootstrap::expandMacros(file);
     return compareExtensionFolderWithLastSynchronizedFile(
@@ -282,7 +282,7 @@ OUString makeURL( OUString const & baseURL, OUString const 
& relPath_ )
             // encode for macro expansion: relPath is supposed to have no
             // macros, so encode $, {} \ (bootstrap mimic)
             relPath = encodeForRcFile(relPath);
-            
+
             // encode once more for vnd.sun.star.expand schema:
             // vnd.sun.star.expand:$UNO_...
             // will expand to file-url
@@ -299,7 +299,7 @@ OUString makeURLAppendSysPathSegment( OUString const & 
baseURL, OUString const &
 {
     OUString segment = relPath_;
     OSL_ASSERT(segment.indexOf(static_cast<sal_Unicode>('/')) == -1);
-    
+
     ::rtl::Uri::encode(
         segment, rtl_UriCharClassPchar, rtl_UriEncodeIgnoreEscapes,
         RTL_TEXTENCODING_UTF8);
@@ -362,10 +362,10 @@ bool office_is_running()
     {
         sFile = sFile.copy(sFile.lastIndexOf('/') + 1);
         if (
-#if defined UNIX            
+#if defined UNIX
             sFile.equals(OUString(RTL_CONSTASCII_USTRINGPARAM(SOFFICE2)))
 #elif defined WNT || defined OS2
-            //osl_getExecutableFile should deliver "soffice.bin" on windows
+            //osl_getExecutableFile should deliver "soffice.bin" on Windows
             //even if swriter.exe, scalc.exe etc. was started. This is a bug
             //in osl_getExecutableFile
             sFile.equals(OUString(RTL_CONSTASCII_USTRINGPARAM(SOFFICE1)))
@@ -377,8 +377,8 @@ bool office_is_running()
             || sFile.equals(OUString(RTL_CONSTASCII_USTRINGPARAM(SWRITER)))
 #else
 #error "Unsupported platform"
-#endif            
-            
+#endif
+
             )
             ret = true;
         else
@@ -388,7 +388,7 @@ bool office_is_running()
     {
         OSL_ENSURE(0, "NOT osl_Process_E_None ");
         //if osl_getExecutable file than we take the risk of creating a pipe
-        ret =  existsOfficePipe();  
+        ret = existsOfficePipe();
     }
     return ret;
 }
@@ -409,14 +409,14 @@ oslProcess raiseProcess(
         0, // => current working dir
         0, 0, // => no env vars
         &hProcess );
-    
+
     switch (rc) {
     case osl_Process_E_None:
         break;
     case osl_Process_E_NotFound:
         throw RuntimeException( OUSTR("image not found!"), 0 );
     case osl_Process_E_TimedOut:
-        throw RuntimeException( OUSTR("timout occurred!"), 0 );
+        throw RuntimeException( OUSTR("timeout occurred!"), 0 );
     case osl_Process_E_NoPermission:
         throw RuntimeException( OUSTR("permission denied!"), 0 );
     case osl_Process_E_Unknown:
@@ -425,7 +425,7 @@ oslProcess raiseProcess(
     default:
         throw RuntimeException( OUSTR("unmapped error!"), 0 );
     }
-    
+
     return hProcess;
 }
 
@@ -456,7 +456,7 @@ Reference<XInterface> resolveUnoURL(
 {
     Reference<bridge::XUnoUrlResolver> xUnoUrlResolver(
         bridge::UnoUrlResolver::create( xLocalContext ) );
-    
+
     for (;;)
     {
         if (abortChannel != 0 && abortChannel->isAborted()) {
@@ -477,7 +477,7 @@ Reference<XInterface> resolveUnoURL(
 void writeConsoleWithStream(::rtl::OUString const & sText, HANDLE stream)
 {
     DWORD nWrittenChars = 0;
-    WriteFile(stream, sText.getStr(), 
+    WriteFile(stream, sText.getStr(),
         sText.getLength() * 2, &nWrittenChars, NULL);
 }
 #else
@@ -591,13 +591,13 @@ void syncRepositories(Reference<ucb::XCommandEnvironment> 
const & xCmdEnv)
         return;
 
     Reference<deployment::XExtensionManager> xExtensionManager;
-    //synchronize shared before bundled otherewise there are
+    //synchronize shared before bundled otherwise there are
     //more revoke and registration calls.
     sal_Bool bModified = false;
     if (needToSyncRepostitory(OUString(RTL_CONSTASCII_USTRINGPARAM("shared")))
         || 
needToSyncRepostitory(OUString(RTL_CONSTASCII_USTRINGPARAM("bundled"))))
     {
-        xExtensionManager =          
+        xExtensionManager =
             deployment::ExtensionManager::get(
                 comphelper_getProcessComponentContext());
 
diff --git a/main/offapi/com/sun/star/awt/AccessibleButton.idl 
b/main/offapi/com/sun/star/awt/AccessibleButton.idl
index bc15854..fadc38a 100644
--- a/main/offapi/com/sun/star/awt/AccessibleButton.idl
+++ b/main/offapi/com/sun/star/awt/AccessibleButton.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -47,23 +47,23 @@
 #endif
 
 module com { module sun { module star { module awt {
-    
+
 /** specifies accessibility support for a button.
 
     @since OpenOffice 1.1.2
- */    
+ */
 published service AccessibleButton
 {
     /** This interface gives access to the structural information of a button:
 
         <ul>
-        <li>Role: The role of a button is <const 
+        <li>Role: The role of a button is <const
             scope="com::sun::star::accessibility"
             >AccessibleRole::PUSH_BUTTON</const>.</li>
         <li>Name: The name of a button is its localized label.</li>
         <li>Description: The description of a button is its localized
             help text.</li>
-        <li>Children: There are no children.</li>            
+        <li>Children: There are no children.</li>
         <li>Parent: The parent is the window that contains the button.</li>
         <li>Relations: There are no relations.</li>
         <li>States: The states supported by this service are
@@ -98,16 +98,16 @@ published service AccessibleButton
         </ul>
      */
     interface ::com::sun::star::accessibility::XAccessibleContext;
-    
+
     interface ::com::sun::star::accessibility::XAccessibleEventBroadcaster;
-    
+
     interface ::com::sun::star::accessibility::XAccessibleComponent;
-    
+
     interface ::com::sun::star::accessibility::XAccessibleExtendedComponent;
 
     /** This interface gives read-only access to the text representation
         of a button.
-     */    
+     */
     interface ::com::sun::star::accessibility::XAccessibleText;
 
     /** This interface gives access to the actions that can be executed for
@@ -119,14 +119,14 @@ published service AccessibleButton
     interface ::com::sun::star::accessibility::XAccessibleAction;
 
     /** This interface gives access to the numerical value of a button,
-        which is related to the button's 
+        which is related to the button's
         <const scope="com::sun::star::accessibility"
         >AccessibleStateType::PRESSED</const> state.
      */
     interface ::com::sun::star::accessibility::XAccessibleValue;
-    
+
 };
-          
+
 }; }; }; };
 
 #endif
diff --git a/main/offapi/com/sun/star/awt/AccessibleCheckBox.idl 
b/main/offapi/com/sun/star/awt/AccessibleCheckBox.idl
index 414b541..370f776 100644
--- a/main/offapi/com/sun/star/awt/AccessibleCheckBox.idl
+++ b/main/offapi/com/sun/star/awt/AccessibleCheckBox.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -47,18 +47,18 @@
 #endif
 
 module com { module sun { module star { module awt {
-    
+
 /** specifies accessibility support for a check box.
-    
-    @since OpenOffice 1.1.2    
- */    
+
+    @since OpenOffice 1.1.2
+ */
 published service AccessibleCheckBox
 {
     /** This interface gives access to the structural information of a
         check box:
 
         <ul>
-        <li>Role: The role of a check box is <const 
+        <li>Role: The role of a check box is <const
             scope="com::sun::star::accessibility"
             >AccessibleRole::CHECK_BOX</const>.</li>
         <li>Name: The name of a check box is its localized label.</li>
@@ -71,11 +71,11 @@ published service AccessibleCheckBox
             <ul>
             <li><const scope="com::sun::star::accessibility"
                 >AccessibleStateType::CHECKED</const> is set
-                if the object is currently checked.</li>        
+                if the object is currently checked.</li>
             <li><const scope="com::sun::star::accessibility"
                 >AccessibleStateType::DEFUNC</const>
                 is set if the object has already been disposed
-                and subsequent calls to this object result in                  
        
+                and subsequent calls to this object result in
                 <type scope="com::sun::star::lang">DisposedException</type>
                 exceptions.</li>
             <li><const scope="com::sun::star::accessibility"
@@ -96,18 +96,18 @@ published service AccessibleCheckBox
         </ul>
      */
     interface ::com::sun::star::accessibility::XAccessibleContext;
-    
+
     interface ::com::sun::star::accessibility::XAccessibleEventBroadcaster;
-    
+
     interface ::com::sun::star::accessibility::XAccessibleComponent;
-    
+
     interface ::com::sun::star::accessibility::XAccessibleExtendedComponent;
-    
+
     /** This interface gives read-only access to the text representation
         of a check box.
      */
     interface ::com::sun::star::accessibility::XAccessibleText;
-    
+
     /** This interface gives access to the actions that can be executed for
         a check box. The supported actions for a check box are:
         <ul>
diff --git a/main/offapi/com/sun/star/awt/Command.idl 
b/main/offapi/com/sun/star/awt/Command.idl
index d98b80e..fcb1afe 100644
--- a/main/offapi/com/sun/star/awt/Command.idl
+++ b/main/offapi/com/sun/star/awt/Command.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -26,7 +26,7 @@
 
 //=============================================================================
 
-module com {  module sun {  module star {  module awt {
+module com { module sun { module star { module awt {
 
 /** these values specify the different command types available.
 */
@@ -34,96 +34,96 @@ module com {  module sun {  module star {  module awt {
 published constants Command
 {
 
-       
//------------------------------------------------------------------------- 
-    
-    /** specifies a requests for a context menu.
+       
//-------------------------------------------------------------------------
+
+    /** specifies a request for a context menu.
     */
     const short CONTEXTMENU = 1;
 
-       
//------------------------------------------------------------------------- 
+       
//-------------------------------------------------------------------------
 
     /** specifies the beginning of a drag operation.
     */
     const short STARTDRAG = 2;
-       
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies a mouse wheel operation.
     */
     const short WHEEL = 3;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies the beginning of an auto scroll operation.
     */
     const short STARTAUTOSCROLL = 4;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies an auto scroll operation.
     */
     const short AUTOSCROLL = 5;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies a request for a voice operation.
     */
     const short VOICE = 6;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies the beginning of an extended text input operation.
     */
     const short STARTEXTTEXTINPUT = 7;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies an extended text input operation.
     */
     const short EXTTEXTINPUT = 8;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies the end of an extended text input operation.
     */
     const short ENDEXTTEXTINPUT = 9;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies that the input context has been changed.
     */
     const short INPUTCONTEXTCHANGE = 10;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies the cursor position.
     */
     const short CURSORPOS = 11;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies a paste selection command.
     */
     const short PASTESELECTION = 12;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies that the state of a key modifier has changed.
     */
     const short MODKEYCHANGE = 13;
-    
-       
//------------------------------------------------------------------------- 
-    
-    /** specifies a hangual hanja conversion command.
+
+       
//-------------------------------------------------------------------------
+
+    /** specifies a hangul hanja conversion command.
     */
     const short HANGUL_HANJA_CONVERSION = 14;
-    
-       
//------------------------------------------------------------------------- 
-    
+
+       
//-------------------------------------------------------------------------
+
     /** specifies a user-defined command.
     */
     const short USER = 4096;
-};          
+};
 
 }; }; }; };
 
diff --git a/main/offapi/com/sun/star/awt/WindowAttribute.idl 
b/main/offapi/com/sun/star/awt/WindowAttribute.idl
index 26cd804..4d07111 100644
--- a/main/offapi/com/sun/star/awt/WindowAttribute.idl
+++ b/main/offapi/com/sun/star/awt/WindowAttribute.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,125 +7,126 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
-#ifndef __com_sun_star_awt_WindowAttribute_idl__ 
-#define __com_sun_star_awt_WindowAttribute_idl__ 
- 
- 
-//=============================================================================
 
- 
- module com {  module sun {  module star {  module awt {  
- 
-//=============================================================================
 
- 
+
+#ifndef __com_sun_star_awt_WindowAttribute_idl__
+#define __com_sun_star_awt_WindowAttribute_idl__
+
+
+//=============================================================================
+
+ module com { module sun { module star { module awt {
+
+//=============================================================================
+
 /** These values are used to specify the decorations of a window.
 
-       <p><b>IMPORTANT:</b> These constands have to be disjunct with
+       <p><b>IMPORTANT:</b> These constants have to be disjunct with
        constants in <type>VclWindowPeerAttribute</type>.</p>
  */
 published constants WindowAttribute
-{ 
-       
//------------------------------------------------------------------------- 
-        
+{
+       
//-------------------------------------------------------------------------
+
        /** specifies that the window is initially visible.
         */
-       const long SHOW = 1; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the window fills the complete desktop area. 
-                                
+       const long SHOW = 1;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the window fills the complete desktop area.
+
                <p>This applies only to top windows.</p>
         */
-       const long FULLSIZE = 2; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the window is optimum size. 
-                                
+       const long FULLSIZE = 2;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the window is optimum size.
+
                <p>This applies only to top windows.</p>
         */
-       const long OPTIMUMSIZE = 4; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the window is minimum size. 
-                                
+       const long OPTIMUMSIZE = 4;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the window is minimum size.
+
                <p>This applies only to top windows.</p>
         */
-       const long MINSIZE = 8; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the window has visible borders. 
-                                
+       const long MINSIZE = 8;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the window has visible borders.
+
                <p>This applies only to top windows.</p>
         */
-       const long BORDER = 16; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the size of the window can be changed by the user. 
+       const long BORDER = 16;
 
-               <p>This applies only to top windows.</p>    
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the size of the window can be changed by the user.
+
+               <p>This applies only to top windows.</p>
         */
-       const long SIZEABLE = 32; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the window can be moved by the user. 
+       const long SIZEABLE = 32;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the window can be moved by the user.
 
-               <p>This applies only to top windows.</p>    
+               <p>This applies only to top windows.</p>
         */
-       const long MOVEABLE = 64; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the window can be closed by the user. 
+       const long MOVEABLE = 64;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the window can be closed by the user.
 
-               <p>This applies only to top windows.</p>    
+               <p>This applies only to top windows.</p>
         */
-       const long CLOSEABLE = 128; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the window should support the 
+       const long CLOSEABLE = 128;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the window should support the
                <type 
scope="com::sun::star::awt::">XSystemDependentWindowPeer</type>
-        interface.  
-                                
-               <p>This flag may be ignored, but in this case no 
system-dependent  
+               interface.
+
+               <p>This flag may be ignored, but in this case no 
system-dependent
                extension works.</p>
-                                
-               @see XSystemDependentWindowPeer 
+
+               @see XSystemDependentWindowPeer
                @see com::sun::star::lang::SystemDependent
 
                @deprecated
                        conflicts with 
<member>VclWindowPeerAttribute::HSCROLL</member>
         */
-       const long SYSTEMDEPENDENT = 256; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies that the window should have no decoration. 
+       const long SYSTEMDEPENDENT = 256;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies that the window should have no decoration.
         */
-    const long NODECORATION = 512;
-
-}; 
- 
-//=============================================================================
 
- 
-}; }; }; };  
- 
+       const long NODECORATION = 512;
+
+};
+
+//=============================================================================
+
+}; }; }; };
+
 #endif 
diff --git a/main/offapi/com/sun/star/awt/WindowEvent.idl 
b/main/offapi/com/sun/star/awt/WindowEvent.idl
index bef6337..1d55c3b 100644
--- a/main/offapi/com/sun/star/awt/WindowEvent.idl
+++ b/main/offapi/com/sun/star/awt/WindowEvent.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,101 +7,101 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
-#ifndef __com_sun_star_awt_WindowEvent_idl__ 
-#define __com_sun_star_awt_WindowEvent_idl__ 
- 
-#ifndef __com_sun_star_lang_EventObject_idl__ 
-#include <com/sun/star/lang/EventObject.idl> 
-#endif 
- 
- 
-//=============================================================================
 
- 
- module com {  module sun {  module star {  module awt {  
- 
-//=============================================================================
 
- 
+#ifndef __com_sun_star_awt_WindowEvent_idl__
+#define __com_sun_star_awt_WindowEvent_idl__
+
+#ifndef __com_sun_star_lang_EventObject_idl__
+#include <com/sun/star/lang/EventObject.idl>
+#endif
+
+
+//=============================================================================
+
+ module com { module sun { module star { module awt {
+
+//=============================================================================
+
 /** specifies a window event.
  */
 published struct WindowEvent: com::sun::star::lang::EventObject
-{ 
-       
//------------------------------------------------------------------------- 
-        
+{
+       
//-------------------------------------------------------------------------
+
        /** specifies the outer x position of the window.
         */
-       long X; 
- 
-       
//------------------------------------------------------------------------- 
-        
+       long X;
+
+       
//-------------------------------------------------------------------------
+
        /** specifies the outer y position of the window.
         */
-       long Y; 
- 
-       
//------------------------------------------------------------------------- 
-        
+       long Y;
+
+       
//-------------------------------------------------------------------------
+
        /** specifies the outer (total) width of the window.
         */
-       long Width; 
- 
-       
//------------------------------------------------------------------------- 
-        
+       long Width;
+
+       
//-------------------------------------------------------------------------
+
        /** specifies the outer (total) height of the window.
         */
-       long Height; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies the inset from the left. 
-                                               
+       long Height;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies the inset from the left.
+
                <p>The inset is the distance between the outer and the inner 
window,
                that means the left inset is the width of the left border.</p>
         */
-       long LeftInset; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies the inset from the top. 
-                                               
+       long LeftInset;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies the inset from the top.
+
                <p>The inset is the distance between the outer and the inner 
window,
-               that means the top inset is the heigt of the top border.</p>
+               that means the top inset is the height of the top border.</p>
         */
-       long TopInset; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies the inset from the right. 
-                                               
+       long TopInset;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies the inset from the right.
+
                <p>The inset is the distance between the outer and the inner 
window,
                that means the right inset is the width of the right border.</p>
         */
-       long RightInset; 
- 
-       
//------------------------------------------------------------------------- 
-        
-       /** specifies the inset from the bottom. 
-                                               
+       long RightInset;
+
+       
//-------------------------------------------------------------------------
+
+       /** specifies the inset from the bottom.
+
                <p>The inset is the distance between the outer and the inner 
window,
-               that means the bottom inset is the heigt of the bottom 
border.</p>
+               that means the bottom inset is the height of the bottom 
border.</p>
         */
-       long BottomInset; 
- 
-}; 
- 
-//=============================================================================
 
- 
-}; }; }; };  
- 
+       long BottomInset;
+
+};
+
+//=============================================================================
+
+}; }; }; };
+
 #endif 
diff --git a/main/offapi/com/sun/star/awt/grid/DefaultGridColumnModel.idl 
b/main/offapi/com/sun/star/awt/grid/DefaultGridColumnModel.idl
index e1e3629..ca893cb 100644
--- a/main/offapi/com/sun/star/awt/grid/DefaultGridColumnModel.idl
+++ b/main/offapi/com/sun/star/awt/grid/DefaultGridColumnModel.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,42 +7,43 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
+
 #ifndef __com_sun_star_awt_DefaultGridColumnModel_idl__
 #define __com_sun_star_awt_DefaultGridColumnModel_idl__
- 
-#ifndef __com_sun_star_awt_grid_XGridColumnModel_idl__ 
-#include <com/sun/star/awt/grid/XGridColumnModel.idl> 
+
+#ifndef __com_sun_star_awt_grid_XGridColumnModel_idl__
+#include <com/sun/star/awt/grid/XGridColumnModel.idl>
 #endif
 
-//=============================================================================
 
- 
- module com {  module sun {  module star {  module awt {  module grid {
- 
-//=============================================================================
 
- 
+//=============================================================================
+
+ module com { module sun { module star { module awt { module grid {
+
+//=============================================================================
+
 /** If you do not want to implement the <type>XGridColumnModel</type> 
yourself, use this service.
        @since OpenOffice 3.3
- */ 
+ */
 service DefaultGridColumnModel
-{ 
+{
        interface com::sun::star::awt::grid::XGridColumnModel;
-}; 
- 
-//=============================================================================
 
- 
+};
+
+//=============================================================================
+
 }; }; }; };};
- 
+
 #endif 
diff --git a/main/offapi/com/sun/star/awt/tree/XTreeEditListener.idl 
b/main/offapi/com/sun/star/awt/tree/XTreeEditListener.idl
index 17f4f4e..b6bb449 100644
--- a/main/offapi/com/sun/star/awt/tree/XTreeEditListener.idl
+++ b/main/offapi/com/sun/star/awt/tree/XTreeEditListener.idl
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,19 +7,20 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
+
 #ifndef __com_sun_star_awt_tree_XTreeEditListener_idl__
 #define __com_sun_star_awt_tree_XTreeEditListener_idl__
 
@@ -37,12 +38,12 @@
 
 //=============================================================================
 
-module com {  module sun {  module star {  module awt {  module tree {
+module com { module sun { module star { module awt { module tree {
 
 //=============================================================================
 
 /** You can implement this interface and register with <method 
scope="XTreeControl">addTreeEditListener</method>
-    to get notifcaitons when editing of a node starts and ends.
+    to get notifications when editing of a node starts and ends.
 
     <p>You have to set the <member>TreeControlModel::Editable</member> 
property to
     <TRUE/> before a tree supports editing.</p>
diff --git a/main/sc/source/ui/Accessibility/AccessibleFilterMenu.cxx 
b/main/sc/source/ui/Accessibility/AccessibleFilterMenu.cxx
index 50ed9eb..2dad23f 100644
--- a/main/sc/source/ui/Accessibility/AccessibleFilterMenu.cxx
+++ b/main/sc/source/ui/Accessibility/AccessibleFilterMenu.cxx
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -67,7 +67,7 @@ namespace {
 class AddRemoveEventListener : public ::std::unary_function<void, 
Reference<XAccessible> >
 {
 public:
-    explicit AddRemoveEventListener(const Reference<XAccessibleEventListener>& 
rListener, bool bAdd) : 
+    explicit AddRemoveEventListener(const Reference<XAccessibleEventListener>& 
rListener, bool bAdd) :
         mxListener(rListener), mbAdd(bAdd) {}
 
     void operator() (const Reference<XAccessible>& xAccessible) const
@@ -125,13 +125,13 @@ void ScAccessibleFilterMenu::grabFocus()
 {
 }
 
-sal_Int32 ScAccessibleFilterMenu::getForeground() 
+sal_Int32 ScAccessibleFilterMenu::getForeground()
     throw (RuntimeException)
 {
     return 0;
 }
 
-sal_Int32 ScAccessibleFilterMenu::getBackground() 
+sal_Int32 ScAccessibleFilterMenu::getBackground()
     throw (RuntimeException)
 {
     return 0;
@@ -144,13 +144,13 @@ OUString ScAccessibleFilterMenu::getAccessibleName() 
throw (RuntimeException)
     return ScAccessibleContextBase::getAccessibleName();
 }
 
-sal_Int32 ScAccessibleFilterMenu::getAccessibleChildCount() 
+sal_Int32 ScAccessibleFilterMenu::getAccessibleChildCount()
     throw (RuntimeException)
 {
     return getMenuItemCount();
 }
 
-Reference<XAccessible> ScAccessibleFilterMenu::getAccessibleChild(sal_Int32 
nIndex) 
+Reference<XAccessible> ScAccessibleFilterMenu::getAccessibleChild(sal_Int32 
nIndex)
     throw (RuntimeException, IndexOutOfBoundsException)
 {
     if (maMenuItems.size() <= static_cast<size_t>(nIndex))
@@ -159,14 +159,14 @@ Reference<XAccessible> 
ScAccessibleFilterMenu::getAccessibleChild(sal_Int32 nInd
     return maMenuItems[nIndex];
 }
 
-Reference<XAccessibleStateSet> ScAccessibleFilterMenu::getAccessibleStateSet() 
+Reference<XAccessibleStateSet> ScAccessibleFilterMenu::getAccessibleStateSet()
     throw (RuntimeException)
 {
     updateStates();
     return mxStateSet;
 }
 
-OUString ScAccessibleFilterMenu::getImplementationName() 
+OUString ScAccessibleFilterMenu::getImplementationName()
     throw (RuntimeException)
 {
     return OUString::createFromAscii("ScAccessibleFilterMenu");
@@ -194,7 +194,7 @@ void ScAccessibleFilterMenu::removeEventListener(
 
 // XAccessibleSelection
 
-void ScAccessibleFilterMenu::selectAccessibleChild(sal_Int32 nChildIndex) 
+void ScAccessibleFilterMenu::selectAccessibleChild(sal_Int32 nChildIndex)
     throw (IndexOutOfBoundsException, RuntimeException)
 {
     if (static_cast<size_t>(nChildIndex) >= maMenuItems.size())
@@ -203,7 +203,7 @@ void 
ScAccessibleFilterMenu::selectAccessibleChild(sal_Int32 nChildIndex)
     mpWindow->setSelectedMenuItem(nChildIndex, false, true);
 }
 
-sal_Bool ScAccessibleFilterMenu::isAccessibleChildSelected(sal_Int32 
nChildIndex) 
+sal_Bool ScAccessibleFilterMenu::isAccessibleChildSelected(sal_Int32 
nChildIndex)
     throw (IndexOutOfBoundsException, RuntimeException)
 {
     if (static_cast<size_t>(nChildIndex) >= maMenuItems.size())
@@ -219,7 +219,7 @@ void ScAccessibleFilterMenu::clearAccessibleSelection() 
throw (RuntimeException)
 
 void ScAccessibleFilterMenu::selectAllAccessibleChildren() throw 
(RuntimeException)
 {
-    // not suported - this is a menu, you can't select all menu items.
+    // not supported - this is a menu, you can't select all menu items.
 }
 
 sal_Int32 ScAccessibleFilterMenu::getSelectedAccessibleChildCount() throw 
(RuntimeException)
@@ -228,7 +228,7 @@ sal_Int32 
ScAccessibleFilterMenu::getSelectedAccessibleChildCount() throw (Runti
     return mpWindow->getSelectedMenuItem() == 
ScMenuFloatingWindow::MENU_NOT_SELECTED ? 0 : 1;
 }
 
-Reference<XAccessible> 
ScAccessibleFilterMenu::getSelectedAccessibleChild(sal_Int32 nChildIndex) 
+Reference<XAccessible> 
ScAccessibleFilterMenu::getSelectedAccessibleChild(sal_Int32 nChildIndex)
     throw (IndexOutOfBoundsException, RuntimeException)
 {
     if (static_cast<size_t>(nChildIndex) >= maMenuItems.size())
@@ -269,7 +269,7 @@ void SAL_CALL ScAccessibleFilterMenu::release() throw ()
 
 // XTypeProvider
 
-Sequence<sal_Int8> ScAccessibleFilterMenu::getImplementationId() 
+Sequence<sal_Int8> ScAccessibleFilterMenu::getImplementationId()
     throw (RuntimeException)
 {
     Sequence<sal_Int8> aId(16);
@@ -281,8 +281,8 @@ Rectangle ScAccessibleFilterMenu::GetBoundingBoxOnScreen() 
const
 {
     if (mnMenuPos == ScMenuFloatingWindow::MENU_NOT_SELECTED)
         return Rectangle();
-    
-    // Menu object's bounding box is the bounding box of the menu item that 
+
+    // Menu object's bounding box is the bounding box of the menu item that
     // launches the menu, which belongs to the parent window.
     ScMenuFloatingWindow* pParentWin = mpWindow->getParentMenuWindow();
     if (!pParentWin)
@@ -305,7 +305,7 @@ Rectangle ScAccessibleFilterMenu::GetBoundingBox() const
     if (mnMenuPos == ScMenuFloatingWindow::MENU_NOT_SELECTED)
         return Rectangle();
 
-    // Menu object's bounding box is the bounding box of the menu item that 
+    // Menu object's bounding box is the bounding box of the menu item that
     // launches the menu, which belongs to the parent window.
     ScMenuFloatingWindow* pParentWin = mpWindow->getParentMenuWindow();
     if (!pParentWin)
@@ -323,13 +323,13 @@ Rectangle ScAccessibleFilterMenu::GetBoundingBox() const
 
 void ScAccessibleFilterMenu::appendMenuItem(const OUString& rName, bool 
bEnabled, size_t nMenuPos)
 {
-    // Check weather this menu item is a sub menu or a regular menu item.
+    // Check whether this menu item is a sub menu or a regular menu item.
     ScMenuFloatingWindow* pSubMenu = mpWindow->getSubMenuWindow(nMenuPos);
     Reference<XAccessible> xAccessible;
     if (pSubMenu)
     {
         xAccessible = pSubMenu->CreateAccessible();
-        ScAccessibleFilterMenu* p = 
+        ScAccessibleFilterMenu* p =
             static_cast<ScAccessibleFilterMenu*>(xAccessible.get());
         p->setEnabled(bEnabled);
         p->setMenuPos(nMenuPos);
@@ -337,7 +337,7 @@ void ScAccessibleFilterMenu::appendMenuItem(const OUString& 
rName, bool bEnabled
     else
     {
         xAccessible.set(new ScAccessibleFilterMenuItem(this, mpWindow, rName, 
nMenuPos));
-        ScAccessibleFilterMenuItem* p = 
+        ScAccessibleFilterMenuItem* p =
             static_cast<ScAccessibleFilterMenuItem*>(xAccessible.get());
         p->setEnabled(bEnabled);
     }
diff --git a/main/sd/source/ui/slidesorter/inc/cache/SlsPageCache.hxx 
b/main/sd/source/ui/slidesorter/inc/cache/SlsPageCache.hxx
index a12d0ce..17c0007 100644
--- a/main/sd/source/ui/slidesorter/inc/cache/SlsPageCache.hxx
+++ b/main/sd/source/ui/slidesorter/inc/cache/SlsPageCache.hxx
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -44,17 +44,17 @@ class RequestData;
     bitmaps of pages that are shown by the slide sorter.
 
     <p>Bitmaps for previews and a cache are used to speed up the display
-    (painting) of the slide sorter.  But, of course, we have to limit this
+    (painting) of the slide sorter. But, of course, we have to limit this
     time-space-tradeoff by limiting the amount of space that can be use to
     store bitmaps.</p>
 
     <p>There are several strategies employed by this class to shorten the
     perceived time that is used to paint the slide sorter:
     <ul>
-    <li>Rendering pages ahead of time.  Additionally to rendering the
+    <li>Rendering pages ahead of time. Additionally to rendering the
     visible slides we try to render part or all of the slides that are not
-    (yet) visible.  This, of course, makes sense only when the computer is
-    ohterwise idle while doing that.</li>
+    (yet) visible. This, of course, makes sense only when the computer is
+    otherwise idle while doing that.</li>
     <li>When the size of the slides on the screen changes we mark the
     bitmaps as needing an update but use them while the new bitmap in the
     correct size is not available.</li>
@@ -74,7 +74,7 @@ class RequestData;
 class PageCache
 {
 public:
-    /** The page chache is created with a reference to the slide sorter so
+    /** The page cache is created with a reference to the slide sorter so
         that it has access to both the view and the model and so can fill
         itself with requests for all or just the visible pages.
 
@@ -93,19 +93,19 @@ public:
         const bool bDoSuperSampling);
 
     /** Request a preview bitmap for the specified page object in the
-        specified size.  The returned bitmap may be a preview of the
+        specified size. The returned bitmap may be a preview of the
         preview, i.e. either a scaled (up or down) version of a previous
-        preview (of the wrong size) or an empty bitmap.  In this case a
+        preview (of the wrong size) or an empty bitmap. In this case a
         request for the generation of a new preview is created and inserted
-        into the request queue.  When the preview is available in the right
-        size the page shape will be told to paint itself again.  When it
+        into the request queue. When the preview is available in the right
+        size the page shape will be told to paint itself again. When it
         then calls this method again if receives the correctly sized preview
         bitmap.
         @param rRequestData
             This data is used to determine the preview.
         @param bResize
             When <TRUE/> then when the available bitmap has not the
-            requested size, it is scaled before it is returned.  When
+            requested size, it is scaled before it is returned. When
             <FALSE/> then the bitmap is returned in the wrong size and it is
             the task of the caller to scale it.
         @return
@@ -124,13 +124,13 @@ public:
         const Bitmap& rBitmap);
 
     /** When the requested preview bitmap does not yet exist or is not
-        up-to-date then the rendering of one is scheduled.  Otherwise this
+        up-to-date then the rendering of one is scheduled. Otherwise this
         method does nothing.
     */
     void RequestPreviewBitmap (const CacheKey aKey);
 
     /** Tell the cache that the bitmap associated with the given request
-        data is not up-to-date anymore.  This will invalidate all previews
+        data is not up-to-date anymore. This will invalidate all previews
         in other caches that represent the same page as well.
         @param bRequestPreview
             When <TRUE/> then a new preview is requested and will lead
@@ -151,14 +151,14 @@ public:
         changed or when the model has changed.
         @param bUpdateCache
             When this flags is <TRUE/> then requests for updated previews
-            are created.  When it is <FALSE/> the existing previews are only
+            are created. When it is <FALSE/> the existing previews are only
             marked as not being up-to-date anymore.
     */
     void InvalidateCache (const bool bUpdateCache = true);
 
     /** With the precious flag you can control whether a bitmap can be
         removed or reduced in size to make room for other bitmaps or is so
-        precious that it will not touched.  A typical use is to set the
+        precious that it will not touched. A typical use is to set the
         precious flag for exactly the visible pages.
     */
     void SetPreciousFlag (const CacheKey aKey, const bool bIsPrecious);
diff --git a/main/slideshow/source/engine/slide/slideimpl.cxx 
b/main/slideshow/source/engine/slide/slideimpl.cxx
index 4123313..7aae6c8 100644
--- a/main/slideshow/source/engine/slide/slideimpl.cxx
+++ b/main/slideshow/source/engine/slide/slideimpl.cxx
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,16 +7,16 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
@@ -129,7 +129,7 @@ public:
     virtual bool show( bool );
     virtual void hide();
 
-    virtual basegfx::B2ISize getSlideSize() const;            
+    virtual basegfx::B2ISize getSlideSize() const;
     virtual uno::Reference<drawing::XDrawPage > getXDrawPage() const;
     virtual uno::Reference<animations::XAnimationNode> getXAnimationNode() 
const;
     virtual PolyPolygonVector getPolygons();
@@ -178,14 +178,14 @@ private:
     bool isShowing() const;
 
     /// Set all Shapes to their initial attributes for slideshow
-    bool applyInitialShapeAttributes( const ::com::sun::star::uno::Reference< 
+    bool applyInitialShapeAttributes( const ::com::sun::star::uno::Reference<
                                       
::com::sun::star::animations::XAnimationNode >& xRootAnimationNode );
 
     /// Renders current slide content to bitmap
     SlideBitmapSharedPtr createCurrentSlideBitmap(
         const UnoViewSharedPtr& rView,
         ::basegfx::B2ISize const & rSlideSize ) const;
-        
+
     /// Prefetch all shapes (not the animations)
     bool loadShapes();
 
@@ -206,7 +206,7 @@ private:
 
     /// Add Polygons to the member maPolygons
     void addPolygons(PolyPolygonVector aPolygons);
-    
+
     // Types
     // =====
 
@@ -235,9 +235,9 @@ private:
 
     /// The page model object
     uno::Reference< drawing::XDrawPage >                mxDrawPage;
-    uno::Reference< drawing::XDrawPagesSupplier >       mxDrawPagesSupplier;   
 
+    uno::Reference< drawing::XDrawPagesSupplier >       mxDrawPagesSupplier;
     uno::Reference< animations::XAnimationNode >        mxRootNode;
-    
+
     LayerManagerSharedPtr                               mpLayerManager;
     boost::shared_ptr<ShapeManagerImpl>                 mpShapeManager;
     boost::shared_ptr<SubsettableShapeManager>          
mpSubsettableShapeManager;
@@ -251,11 +251,11 @@ private:
     /// Handles the animation and event generation for us
     SlideAnimations                                                            
                maAnimations;
     PolyPolygonVector                                   maPolygons;
-        
+
     RGBColor                                            maUserPaintColor;
     double                                              mdUserPaintStrokeWidth;
     UserPaintOverlaySharedPtr                                                  
mpPaintOverlay;
-    
+
     /// Bitmaps with slide content at various states
     mutable VectorOfVectorOfSlideBitmaps                maSlideBitmaps;
 
@@ -293,9 +293,9 @@ private:
     */
     bool                                                                       
                        mbMainSequenceFound;
 
-    /// When true, show() was called. Slide hidden oherwise.
+    /// When true, show() was called. Slide hidden otherwise.
     bool                                                mbActive;
-    
+
     ///When true, enablePaintOverlay was called and mbUserPaintOverlay = true
     bool                                                mbPaintOverlayActive;
 };
@@ -333,7 +333,7 @@ public:
 
         // clear clip (might have been changed, e.g. from comb
         // transition)
-        pBitmap->clip( ::basegfx::B2DPolyPolygon() ); 
+        pBitmap->clip( ::basegfx::B2DPolyPolygon() );
         pBitmap->draw( pDevicePixelCanvas );
     }
 
@@ -367,7 +367,7 @@ SlideImpl::SlideImpl( const uno::Reference< 
drawing::XDrawPage >&                   xDrawPage,
     mxDrawPage( xDrawPage ),
     mxDrawPagesSupplier( xDrawPages ),
     mxRootNode( xRootNode ),
-    mpLayerManager( new LayerManager( 
+    mpLayerManager( new LayerManager(
                         rViewContainer,
                         getSlideRect(),
                         bDisableAnimationZOrder) ),
@@ -379,10 +379,10 @@ SlideImpl::SlideImpl( const uno::Reference< 
drawing::XDrawPage >&                 xDrawPage,
                         rShapeCursorMap)),
     mpSubsettableShapeManager( mpShapeManager ),
     maContext( mpSubsettableShapeManager,
-               rEventQueue, 
+               rEventQueue,
                rEventMultiplexer,
                rScreenUpdater,
-               rActivitiesQueue, 
+               rActivitiesQueue,
                rUserEventQueue,
                *this,
                rViewContainer,
@@ -435,7 +435,7 @@ SlideImpl::~SlideImpl()
 
         // TODO(Q3): Make sure LayerManager (and thus Shapes) dies
         // first, because SlideShowContext has SubsettableShapeManager
-        // as reference member. 
+        // as reference member.
         mpLayerManager.reset();
     }
 }
@@ -509,13 +509,13 @@ bool SlideImpl::show( bool bSlideBackgoundPainted )
         std::for_each(maContext.mrViewContainer.begin(),
                       maContext.mrViewContainer.end(),
                       boost::mem_fn(&View::clearAll));
-        
+
         std::for_each( maContext.mrViewContainer.begin(),
                        maContext.mrViewContainer.end(),
                        SlideRenderer(*this) );
         maContext.mrScreenUpdater.notifyUpdate();
     }
-        
+
     // ---------------------------------------------------------------
 
     // fire up animations
@@ -585,7 +585,7 @@ void SlideImpl::hide()
 
     // disable shape management & event broadcasting for shapes of this
     // slide. Also disables LayerManager.
-    mpShapeManager->deactivate();        
+    mpShapeManager->deactivate();
 
     // vanish from view
     resetCursor();
@@ -595,7 +595,7 @@ void SlideImpl::hide()
 }
 
 basegfx::B2ISize SlideImpl::getSlideSize() const
-{    
+{
     return maSlideSize;
 }
 
@@ -627,8 +627,8 @@ SlideBitmapSharedPtr SlideImpl::getCurrentSlideBitmap( 
const UnoViewSharedPtr& r
                              boost::bind(
                                  std::equal_to<UnoViewSharedPtr>(),
                                  rView,
-                                 // select view:    
-                                 boost::bind( 
+                                 // select view:
+                                 boost::bind(
                                      
std::select1st<VectorOfVectorOfSlideBitmaps::value_type>(),
                                      _1 )))) == aEnd )
     {
@@ -659,7 +659,7 @@ SlideBitmapSharedPtr SlideImpl::getCurrentSlideBitmap( 
const UnoViewSharedPtr& r
     }
 
     SlideBitmapSharedPtr&     rBitmap( aIter->second.at( meAnimationState ));
-    const ::basegfx::B2ISize& rSlideSize( 
+    const ::basegfx::B2ISize& rSlideSize(
         getSlideSizePixel( getSlideSize(),
                            rView ));
 
@@ -681,8 +681,8 @@ SlideBitmapSharedPtr SlideImpl::getCurrentSlideBitmap( 
const UnoViewSharedPtr& r
 
 void SlideImpl::viewAdded( const UnoViewSharedPtr& rView )
 {
-    maSlideBitmaps.push_back( 
-        std::make_pair( rView, 
+    maSlideBitmaps.push_back(
+        std::make_pair( rView,
                         VectorOfSlideBitmaps(SlideAnimationState_NUM_ENTRIES) 
));
 
     if( mpLayerManager )
@@ -701,10 +701,10 @@ void SlideImpl::viewRemoved( const UnoViewSharedPtr& 
rView )
                         boost::bind(
                             std::equal_to<UnoViewSharedPtr>(),
                             rView,
-                            // select view:    
-                            boost::bind( 
+                            // select view:
+                            boost::bind(
                                 
std::select1st<VectorOfVectorOfSlideBitmaps::value_type>(),
-                                _1 ))), 
+                                _1 ))),
         aEnd );
 }
 
@@ -750,22 +750,22 @@ bool SlideImpl::isAnimated()
     return mbHaveAnimations && maAnimations.isAnimated();
 }
 
-SlideBitmapSharedPtr SlideImpl::createCurrentSlideBitmap( const 
UnoViewSharedPtr&   rView, 
+SlideBitmapSharedPtr SlideImpl::createCurrentSlideBitmap( const 
UnoViewSharedPtr&   rView,
                                                           const 
::basegfx::B2ISize& rBmpSize ) const
 {
-    ENSURE_OR_THROW( rView && rView->getCanvas(), 
+    ENSURE_OR_THROW( rView && rView->getCanvas(),
                       "SlideImpl::createCurrentSlideBitmap(): Invalid view" );
-    ENSURE_OR_THROW( mpLayerManager, 
+    ENSURE_OR_THROW( mpLayerManager,
                       "SlideImpl::createCurrentSlideBitmap(): Invalid layer 
manager" );
-    ENSURE_OR_THROW( mbShowLoaded, 
+    ENSURE_OR_THROW( mbShowLoaded,
                       "SlideImpl::createCurrentSlideBitmap(): No show loaded" 
);
 
     ::cppcanvas::CanvasSharedPtr pCanvas( rView->getCanvas() );
 
     // create a bitmap of appropriate size
-    ::cppcanvas::BitmapSharedPtr pBitmap( 
-        ::cppcanvas::BaseGfxFactory::getInstance().createBitmap( 
-            pCanvas, 
+    ::cppcanvas::BitmapSharedPtr pBitmap(
+        ::cppcanvas::BaseGfxFactory::getInstance().createBitmap(
+            pCanvas,
             rBmpSize ) );
 
     ENSURE_OR_THROW( pBitmap,
@@ -776,7 +776,7 @@ SlideBitmapSharedPtr SlideImpl::createCurrentSlideBitmap( 
const UnoViewSharedPtr
     ENSURE_OR_THROW( pBitmapCanvas,
                       "SlideImpl::createCurrentSlideBitmap(): Cannot create 
page bitmap canvas" );
 
-    // apply linear part of destination canvas transformation (linear means in 
this context: 
+    // apply linear part of destination canvas transformation (linear means in 
this context:
     // transformation without any translational components)
     ::basegfx::B2DHomMatrix aLinearTransform( rView->getTransformation() );
     aLinearTransform.set( 0, 2, 0.0 );
@@ -804,7 +804,7 @@ namespace
         void operator()( const uno::Reference< animations::XAnimationNode >& 
xChildNode )
         {
             uno::Sequence< beans::NamedValue > aUserData( 
xChildNode->getUserData() );
-                
+
             if( findNamedValue( aUserData, maSearchKey ) )
             {
                 maMainSequence = xChildNode;
@@ -827,9 +827,9 @@ bool SlideImpl::implPrefetchShow()
     if( mbShowLoaded )
         return true;
 
-    ENSURE_OR_RETURN_FALSE( mxDrawPage.is(), 
+    ENSURE_OR_RETURN_FALSE( mxDrawPage.is(),
                        "SlideImpl::implPrefetchShow(): Invalid draw page" );
-    ENSURE_OR_RETURN_FALSE( mpLayerManager, 
+    ENSURE_OR_RETURN_FALSE( mpLayerManager,
                        "SlideImpl::implPrefetchShow(): Invalid layer manager" 
);
 
     // fetch desired page content
@@ -855,7 +855,7 @@ bool SlideImpl::implPrefetchShow()
                 // _although_ some animation nodes are there -
                 // this is an error (not finding animations at
                 // all is okay - might be a static slide)
-                return false; 
+                return false;
             }
 
             // now check whether we've got a main sequence (if
@@ -919,15 +919,15 @@ void SlideImpl::activatePaintOverlay()
 
 void SlideImpl::drawPolygons() const
 {
-    if( mpPaintOverlay  )
+    if( mpPaintOverlay )
         mpPaintOverlay->drawPolygons();
 }
-    
+
 void SlideImpl::addPolygons(PolyPolygonVector aPolygons)
 {
     if(!aPolygons.empty())
     {
-        for( PolyPolygonVector::iterator aIter=aPolygons.begin(), 
+        for( PolyPolygonVector::iterator aIter=aPolygons.begin(),
                  aEnd=aPolygons.end();
              aIter!=aEnd;
              ++aIter )
@@ -941,7 +941,7 @@ bool SlideImpl::isPaintOverlayActive() const
 {
     return mbPaintOverlayActive;
 }
-    
+
 void SlideImpl::deactivatePaintOverlay()
 {
     if(mbPaintOverlayActive)
@@ -969,12 +969,12 @@ void SlideImpl::startIntrinsicAnimations()
     mpSubsettableShapeManager->notifyIntrinsicAnimationsEnabled();
 }
 
-bool SlideImpl::applyInitialShapeAttributes( 
+bool SlideImpl::applyInitialShapeAttributes(
     const uno::Reference< animations::XAnimationNode >& xRootAnimationNode )
 {
     if( !implPrefetchShow() )
         return false;
-        
+
     if( !xRootAnimationNode.is() )
     {
         meAnimationState = INITIAL_STATE;
@@ -990,28 +990,28 @@ bool SlideImpl::applyInitialShapeAttributes(
         ENSURE_OR_RETURN_FALSE( maContext.mxComponentContext.is(),
                            "SlideImpl::applyInitialShapeAttributes(): Invalid 
component context" );
 
-        uno::Reference<lang::XMultiComponentFactory> xFac( 
+        uno::Reference<lang::XMultiComponentFactory> xFac(
             maContext.mxComponentContext->getServiceManager() );
 
         xPropsCreator.set(
             xFac->createInstanceWithContext(
                 ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
                                      
"com.sun.star.animations.TargetPropertiesCreator") ),
-                maContext.mxComponentContext ), 
+                maContext.mxComponentContext ),
             uno::UNO_QUERY_THROW );
     }
     catch( uno::RuntimeException& )
     {
         throw;
     }
-    catch( uno::Exception& ) 
+    catch( uno::Exception& )
     {
         OSL_ENSURE(
             false,
             rtl::OUStringToOString(
                 comphelper::anyToString(cppu::getCaughtException()),
                 RTL_TEXTENCODING_UTF8 ) );
-            
+
         // could not determine initial shape attributes - this
         // is an error, as some effects might then be plainly
         // invisible
@@ -1031,11 +1031,11 @@ bool SlideImpl::applyInitialShapeAttributes(
         uno::Reference< drawing::XShape > xShape( aProps[i].Target,
                                                   uno::UNO_QUERY );
 
-        if( !xShape.is() ) 
+        if( !xShape.is() )
         {
             // not a shape target. Maybe a ParagraphTarget?
             presentation::ParagraphTarget aParaTarget;
-                
+
             if( (aProps[i].Target >>= aParaTarget) )
             {
                 // yep, ParagraphTarget found - extract shape
@@ -1056,7 +1056,7 @@ bool SlideImpl::applyInitialShapeAttributes(
                 continue;
             }
 
-            AttributableShapeSharedPtr pAttrShape( 
+            AttributableShapeSharedPtr pAttrShape(
                 ::boost::dynamic_pointer_cast< AttributableShape >( pShape ) );
 
             if( !pAttrShape )
@@ -1073,7 +1073,7 @@ bool SlideImpl::applyInitialShapeAttributes(
                 // this up first.
                 const DocTreeNodeSupplier& rNodeSupplier( 
pAttrShape->getTreeNodeSupplier() );
 
-                pAttrShape = pAttrShape->getSubset( 
+                pAttrShape = pAttrShape->getSubset(
                     rNodeSupplier.getTreeNode(
                         nParaIndex,
                         DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ) );
@@ -1120,9 +1120,9 @@ bool SlideImpl::loadShapes()
     if( mbShapesLoaded )
         return true;
 
-    ENSURE_OR_RETURN_FALSE( mxDrawPage.is(), 
+    ENSURE_OR_RETURN_FALSE( mxDrawPage.is(),
                        "SlideImpl::loadShapes(): Invalid draw page" );
-    ENSURE_OR_RETURN_FALSE( mpLayerManager, 
+    ENSURE_OR_RETURN_FALSE( mpLayerManager,
                        "SlideImpl::loadShapes(): Invalid layer manager" );
 
     // fetch desired page content
@@ -1133,12 +1133,12 @@ bool SlideImpl::loadShapes()
     uno::Reference< drawing::XShapes >   xMasterPageShapes;
     sal_Int32                            nCurrCount(0);
 
-    uno::Reference< drawing::XMasterPageTarget > xMasterPageTarget( 
mxDrawPage, 
+    uno::Reference< drawing::XMasterPageTarget > xMasterPageTarget( mxDrawPage,
                                                                     
uno::UNO_QUERY );
     if( xMasterPageTarget.is() )
     {
         xMasterPage = xMasterPageTarget->getMasterPage();
-        xMasterPageShapes.set( xMasterPage, 
+        xMasterPageShapes.set( xMasterPage,
                                uno::UNO_QUERY );
 
         if( xMasterPage.is() && xMasterPageShapes.is() )
@@ -1150,25 +1150,25 @@ bool SlideImpl::loadShapes()
             {
                 // load the masterpage shapes
                 // 
-------------------------------------------------------------------------
-                ShapeImporter aMPShapesFunctor( xMasterPage, 
+                ShapeImporter aMPShapesFunctor( xMasterPage,
                                                 mxDrawPage,
                                                 mxDrawPagesSupplier,
                                                 maContext,
                                                 0, /* shape num starts at 0 */
                                                 true );
 
-                mpLayerManager->addShape( 
+                mpLayerManager->addShape(
                     aMPShapesFunctor.importBackgroundShape() );
 
                 while( !aMPShapesFunctor.isImportDone() )
                 {
-                    ShapeSharedPtr const& rShape( 
+                    ShapeSharedPtr const& rShape(
                         aMPShapesFunctor.importShape() );
                     if( rShape )
                         mpLayerManager->addShape( rShape );
                 }
                 addPolygons(aMPShapesFunctor.getPolygons());
-                
+
                 nCurrCount = xMasterPageShapes->getCount() + 1;
             }
             catch( uno::RuntimeException& )
@@ -1188,7 +1188,7 @@ bool SlideImpl::loadShapes()
                 OSL_ENSURE( false,
                             rtl::OUStringToOString(
                                 comphelper::anyToString( 
cppu::getCaughtException() ),
-                                RTL_TEXTENCODING_UTF8 ).getStr() ); 
+                                RTL_TEXTENCODING_UTF8 ).getStr() );
 
                 return false;
             }
@@ -1200,16 +1200,16 @@ bool SlideImpl::loadShapes()
         // load the normal page shapes
         // 
-------------------------------------------------------------------------
 
-        ShapeImporter aShapesFunctor( mxDrawPage, 
+        ShapeImporter aShapesFunctor( mxDrawPage,
                                       mxDrawPage,
                                       mxDrawPagesSupplier,
                                       maContext,
-                                      nCurrCount, 
+                                      nCurrCount,
                                       false );
 
         while( !aShapesFunctor.isImportDone() )
         {
-            ShapeSharedPtr const& rShape( 
+            ShapeSharedPtr const& rShape(
                 aShapesFunctor.importShape() );
             if( rShape )
                 mpLayerManager->addShape( rShape );
@@ -1243,10 +1243,10 @@ bool SlideImpl::loadShapes()
 }
 
 basegfx::B2ISize SlideImpl::getSlideSizeImpl() const
-{    
+{
     uno::Reference< beans::XPropertySet > xPropSet(
         mxDrawPage, uno::UNO_QUERY_THROW );
-        
+
     sal_Int32 nDocWidth = 0;
     sal_Int32 nDocHeight = 0;
     xPropSet->getPropertyValue( ::rtl::OUString( 
RTL_CONSTASCII_USTRINGPARAM("Width") ) ) >>= nDocWidth;
@@ -1280,7 +1280,7 @@ SlideSharedPtr createSlide( const uno::Reference< 
drawing::XDrawPage >&                   xDrawP
 {
     boost::shared_ptr<SlideImpl> pRet( new SlideImpl( xDrawPage, xDrawPages, 
xRootNode, rEventQueue,
                                                       rEventMultiplexer, 
rScreenUpdater,
-                                                      rActivitiesQueue, 
rUserEventQueue, 
+                                                      rActivitiesQueue, 
rUserEventQueue,
                                                       rCursorManager, 
rViewContainer,
                                                       xComponentContext, 
rShapeListenerMap,
                                                       rShapeCursorMap, 
rPolyPolygonVector, rUserPaintColor,

Reply via email to
diff --git a/main/framework/source/inc/loadenv/loadenv.hxx 
b/main/framework/source/inc/loadenv/loadenv.hxx
index 7703d86..cad9077 100644
--- a/main/framework/source/inc/loadenv/loadenv.hxx
+++ b/main/framework/source/inc/loadenv/loadenv.hxx
@@ -1,5 +1,5 @@
 /**************************************************************
- * 
+ *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -7,19 +7,20 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *   http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
  * under the License.
- * 
+ *
  *************************************************************/
 
 
+
 #ifndef __FRAMEWORK_LOADENV_LOADENV_HXX_
 #define __FRAMEWORK_LOADENV_LOADENV_HXX_
 
@@ -64,7 +65,7 @@ class QuietInteraction;
 //_______________________________________________
 // definitions
 
-/** @short  implements general mechainsm for loading documents.
+/** @short  implements general mechanism for loading documents.
 
     @descr  An instance of this class can be used inside the API calls
             XComponentLoader::loadComponentFromURL() and XDispatch::dispatch()
@@ -84,7 +85,7 @@ class LoadEnv : private ThreadHelpBase
 
             @desrc  Such features must outcome without
                     any special parameters.
-                    To make enableing/disabling of
+                    To make enabling/disabling of
                     features very easy (e.g. at the ctor of
                     this class) these values must be combinable
                     as flags. That means: its values must be in
@@ -211,7 +212,7 @@ class LoadEnv : private ThreadHelpBase
         /** @short  holds the information about the finished load process.
 
             @descr  The content of m_xTargetFrame can't be used as valid 
indicator,
-                    (in case the micht existing old document was reactivated)
+                    (in case the might existing old document was reactivated)
                     we must hold the result of the load process explicitly.
          */
         sal_Bool m_bLoaded;
@@ -276,7 +277,7 @@ class LoadEnv : private ThreadHelpBase
                     by calling startLoading(). Of course a still running load 
request
                     will be detected here and a suitable exception will be 
thrown.
                     Such constellation can be detected outside by using 
provided
-                    synchronisation methods or callbacks.
+                    synchronization methods or callbacks.
 
             @param  sURL
                     points to the resource, which should be loaded.
@@ -307,12 +308,12 @@ class LoadEnv : private ThreadHelpBase
                     might expensive check.
                     That can be useful in case this information is needed 
outside too,
                     to decide if its necessary to create some resources for 
this load
-                    request ... or to reject the request imidiatly if it seems 
to be not
+                    request ... or to reject the request immediately if it 
seems to be not
                     loadable in general.
 
             @throw  A LoadEnvException e.g. if another load operation is till 
in progress
                     or initialization of a new one fail by other reasons.
-                    The real reason, a suitable message and ID will be given 
here immidiatly.
+                    The real reason, a suitable message and ID will be given 
here immediately.
 
             @throw  A RuntimeException in case any internal process indicates, 
that
                     the whole runtime can't be used any longer.
@@ -353,7 +354,7 @@ class LoadEnv : private ThreadHelpBase
 
         //_______________________________________
 
-        /** @short  wait for an alreay running load request (started by calling
+        /** @short  wait for an already running load request (started by 
calling
                     startLoading() before).
 
             @descr  The timeout parameter can be used to wait some times only
@@ -473,7 +474,7 @@ class LoadEnv : private ThreadHelpBase
                     close the frame if it was created before in case loading 
failed.
 
             @throw  A LoadEnvException only in cases, where an internal error 
indicates,
-                    that the complete load environment seems to be not useable 
in general.
+                    that the complete load environment seems to be not usable 
in general.
                     In such cases a RuntimeException would be to hard for the 
outside code :-)
 
             @throw  A RuntimeException in case any internal process indicates, 
that
@@ -498,7 +499,7 @@ class LoadEnv : private ThreadHelpBase
             @attention  Not all types we know, are supported by filters. So it 
does not
                         indicates an error, if no suitable filter(loader etcpp 
will be found
                         for a type. But a type must be detected for the 
specified content.
-                        Otherwise its an error and loading can't be finished 
successfully.
+                        Otherwise it's an error and loading can't be finished 
successfully.
 
             @throw  A LoadEnvException if detection failed.
 
@@ -551,7 +552,7 @@ class LoadEnv : private ThreadHelpBase
         /** @short  tries to use FrameLoader objects for loading.
 
             @descr  First the target frame will be located. If it could be 
found
-                    or new created a filter/frame loader will be instanciated 
and
+                    or new created a filter/frame loader will be instantiated 
and
                     used to load the content into this frame.
                     In case loading failed all new created resources will be
                     removed before a suitable exception is thrown.
@@ -574,7 +575,7 @@ class LoadEnv : private ThreadHelpBase
             @descr  It depends from the set target information, if such
                     search is allowed or not! So this method checks first,
                     if the target is the special one "_default".
-                    If not it returns with an empty result immidatly!
+                    If not it returns with an empty result immediately!
                     In case search is allowed, an existing document with the
                     same URL is searched. If it could be found, the 
corresponding
                     view will get the focus and this method return the 
corresponding frame.
@@ -583,10 +584,10 @@ class LoadEnv : private ThreadHelpBase
                     inside the document, which is related to the jumpmark.
 
             @return A valid reference to the target frame, which contains the 
already loaded content
-                    and could be activated successfully. An empty reference 
oterwhise.
+                    and could be activated successfully. An empty reference 
otherwise.
 
             @throw  A LoadEnvException only in cases, where an internal error 
indicates,
-                    that the complete load environment seems to be not useable 
in general.
+                    that the complete load environment seems to be not usable 
in general.
                     In such cases a RuntimeException would be to hard for the 
outside code :-)
 
             @throw  A RuntimeException in case any internal process indicates, 
that
@@ -597,7 +598,7 @@ class LoadEnv : private ThreadHelpBase
 
         //_______________________________________
 
         /** @short  search for any target frame, which seems to be useable
                     for this load request.
 
             @descr  Because this special feature is bound to the target 
specifier "_default"
@@ -614,12 +615,12 @@ class LoadEnv : private ThreadHelpBase
                     </ul>
 
                     If a suitable target is located it will be locked. That's 
why the last rule
-                    exists! If this method returns a valid frame reference, it 
was locked to be useable
-                    for this load request only. (Dont forget to reset this 
state later!)
+                    exists! If this method returns a valid frame reference, it 
was locked to be usable
+                    for this load request only. (Don't forget to reset this 
state later!)
                     Concurrent LoadEnv instances can synchronize her work be 
using such locks :-) HOPEFULLY
 
             @throw  A LoadEnvException only in cases, where an internal error 
indicates,
-                    that the complete load environment seems to be not useable 
in general.
+                    that the complete load environment seems to be not usable 
in general.
                     In such cases a RuntimeException would be to hard for the 
outside code :-)
 
             @throw  A RuntimeException in case any internal process indicates, 
that
@@ -640,7 +641,7 @@ class LoadEnv : private ThreadHelpBase
                     b) If the document was already shown (e.g. by our progress 
implementation)
                        we do nothing here. The reason  behind: The document 
was already shown ..
                        and it was already make a top window ...
-                       If the user activated another frame inbetween (because 
loading needed some time)
+                       If the user activated another frame in between (because 
loading needed some time)
                        it's not allowed to disturb the user again. Then the 
frame must resists in the background.
                     c) If the frame was not shown before ... but loading of a 
visible document into this frame
                        was finished ... we need both actions: setVisible() and 
toFront().
@@ -660,7 +661,7 @@ class LoadEnv : private ThreadHelpBase
 
         //_______________________________________
 
-        /** @short  checks weather a frame is already used for another load 
request or not.
+        /** @short  checks whether a frame is already used for another load 
request or not.
 
             @descr  Such frames can't be used for our "recycle feature"!
 
@@ -676,7 +677,7 @@ class LoadEnv : private ThreadHelpBase
         //_______________________________________
 
         /** @short  try to determine the used application module
-                    of this load request and applay right position and size
+                    of this load request and apply right position and size
                     for this document window ... hopefully before we show it 
.-)
          */
@@ -597,7 +598,7 @@ class LoadEnv : private ThreadHelpBase
         //_______________________________________
 
-        /** @short  search for any target frame, which seems to be useable
+        /** @short  search for any target frame, which seems to be usable
                     for this load request.
 
         void impl_applyPersistentWindowState(const css::uno::Reference< 
css::awt::XWindow >& xWindow);